translate.convert.po2dtd.redtd

Package translate :: Package convert :: Module po2dtd :: Class redtd |
[hide private]
[frames] | no frames]

# Class redtd

source code

this is a convertor class that creates a new dtd based on a template using translations in a po

Instance Methods | [hide private]
__init__(self, dtdfile) | source code
convertstore(self, inputstore, includefuzzy=False) | source code
handleinunit(self, inunit) | source code